-----BEGIN PGP SIGNED MESSAGE-----
Hash: SHA1

in qt-3.0.4 seems to fail (sigsegv) at  the append("<p>") ( i bet qt bug)
qt-3.0.3 seems to work fine as Arjen says.

btw, in qt-3.0.4 it seems no to be needed the "<p> " thing.

so in the meantime if someone want to read the history with the current cvs 
apply the patch attached. (wont display the duplicated entries) (do a cvs 
update -C plugins/qt-gui/src/mlview3.cpp if you applied the 1.diff before)

-----BEGIN PGP SIGNATURE-----

iD8DBQE9ZDK/UMlRieHkprgRAnN1AKCn9ZpjCVDhgraTaKTQ6cLKdGEqSgCfXuy7
1jWklkaSGn1c2w86jScJzDY=
=xXrz
-----END PGP SIGNATURE-----
Index: plugins/qt-gui/src/mlview3.cpp
===================================================================
RCS file: /cvsroot/licq/qt-gui/src/mlview3.cpp,v
retrieving revision 1.1
diff -u -d -p -r1.1 mlview3.cpp
--- plugins/qt-gui/src/mlview3.cpp	21 Aug 2002 20:15:29 -0000	1.1
+++ plugins/qt-gui/src/mlview3.cpp	22 Aug 2002 00:31:20 -0000
@@ -24,14 +24,15 @@
 #endif
 
 #include <qglobal.h>
-#if QT_VERSION < 300
+#if QT_VERSION >= 300
 
 #include <qfont.h>
 #include <qpainter.h>
 #include <qaccel.h>
 #include <qregexp.h>
 #if USE_KDE
-#include <kurl.h>
+  #include <kurl.h>
+  #include <kapp.h>
 #endif
 
 #include "ewidgets.h"
@@ -55,18 +56,20 @@ void MLViewQt3::appendNoNewLine(const QS
 
 void MLViewQt3::append(const QString& s)
 {
-  if (strcmp(qVersion(), "3.0.0") == 0 ||
-      strcmp(qVersion(), "3.0.1") == 0 ||
-      strcmp(qVersion(), "3.0.2") == 0 ||
-      strcmp(qVersion(), "3.0.3") == 0 || 
-      strcmp(qVersion(), "3.0.4") == 0)
-  {
-     // Workaround --
-     // In those versions, QTextEdit::append didn't add a new paragraph.
-     QTextEdit::append("<p>");
-     QTextEdit::append(s);
-  }
-  QTextEdit::append(s);
+  /*
+   *if (strcmp(qVersion(), "3.0.0") == 0 ||
+   *   strcmp(qVersion(), "3.0.1") == 0 ||
+   *   strcmp(qVersion(), "3.0.2") == 0 ||
+   *   strcmp(qVersion(), "3.0.3") == 0 || 
+   *   strcmp(qVersion(), "3.0.4") == 0)
+   *{
+   *  // Workaround --
+   *  // In those versions, QTextBrowser::append didn't add a new paragraph.
+   *  QTextBrowser::append("<p>");
+   *  QTextBrowser::append(s);
+   *}
+   */
+  QTextBrowser::append(s);
 }
 
 QString MLViewQt3::toRichText(const QString& s, bool highlightURLs)
@@ -120,7 +123,7 @@ QString MLViewQt3::toRichText(const QStr
 
 void MLViewQt3::GotoEnd()
 {
-  moveCursor(QTextEdit::MoveEnd, false);
+  moveCursor(QTextBrowser::MoveEnd, false);
 }
 
 void MLViewQt3::setBackground(const QColor& c)

Reply via email to